@@ -5,8 +5,11 @@ from pathlib import Path
 
 import pkg_resources
 
-from arkindex_cli.commands.imports import add_import_parser
+from arkindex_cli.commands.benchmark import add_benchmark_parser
+from arkindex_cli.commands.classes import add_classes_parser
 from arkindex_cli.commands.login import add_login_parser
+from arkindex_cli.commands.process import add_process_parser
+from arkindex_cli.commands.secrets import add_secrets_parser
 
 
 def get_version():
@@ -23,16 +26,30 @@ def get_version():
 
 def get_parser():
     parser = argparse.ArgumentParser(description="Arkindex command-line tool")
+    parser.add_argument(
+        "-p",
+        "--profile",
+        dest="profile_slug",
+        metavar="SLUG",
+        help="Slug of an Arkindex profile to use instead of the default.",
+    )
+
     version = get_version()
     if version:
         parser.add_argument(
-            "-V", "--version", action="version", version=f"%(prog)s {version}",
+            "-V",
+            "--version",
+            action="version",
+            version=f"%(prog)s {version}",
         )
 
     subcommands = parser.add_subparsers(metavar="subcommand")
 
     add_login_parser(subcommands)
-    add_import_parser(subcommands)
+    add_process_parser(subcommands)
+    add_benchmark_parser(subcommands)
+    add_classes_parser(subcommands)
+    add_secrets_parser(subcommands)
 
     return parser
 
